@@ -14,31 +14,33 @@ from netbox_disk.models import Disk
 class DiskBaseTable(NetBoxTable):
     """Base class for tables displaying Disks"""
 
-    vg_name = tables.Column(
-        linkify=True,
-    )
-    lv_name = tables.Column()
     size = tables.Column()
+    cluster = tables.Column(
+        linkify=True
+    )
 
 
 class DiskTable(DiskBaseTable):
     """Table for displaying Disk objects."""
 
     pk = ToggleColumn()
+    virtual_machine = tables.Column(
+        linkify=True
+    )
 
     class Meta(NetBoxTable.Meta):
         model = Disk
         fields = (
             "pk",
-            "vg_name",
-            "lv_name",
             "size",
+            "cluster",
+            "virtual_machine",
             "description",
         )
         default_columns = (
-            "vg_name",
-            "lv_name",
+            "virtual_machine",
             "size",
+            "cluster",
         )
 
 
@@ -48,12 +50,10 @@ class RelatedDiskTable(DiskBaseTable):
     class Meta(NetBoxTable.Meta):
         model = Disk
         fields = (
-            "vg_name",
-            "lv_name",
             "size",
+            "cluster",
         )
         default_columns = (
-            "vg_name",
-            "lv_name",
             "size",
-        )
\ No newline at end of file
+            "cluster",
+        )
